==> haskell-persistent-2.14.5.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-I1IW7lk0UKKI4mMfJZwTQG
key:                  persistent-2.14.5.1-I1IW7lk0UKKI4mMfJZwTQG
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  344bdd5580d70aeb3a641d445c08ef32
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-I1IW7lk0UKKI4mMfJZwTQG
depends:
    aeson-2.1.2.1-7IgTEIjsesxDBKStPrg8Ee
    attoparsec-0.14.4-Gy8NthJdplC7rvqKUZX715 base-4.16.4.0
    base64-bytestring-1.2.1.0-HHVXuywFN4mBHj78fCyIyn
    blaze-html-0.9.2.0-9MxJnDP1bSQLPRBiL4mEXo bytestring-0.11.4.0
    conduit-1.3.6.1-I0pkWSrZ9L621n2N9S5oir containers-0.6.5.1
    deepseq-1.4.6.1 fast-logger-3.1.2-j7tx9ndiiXEhRN8qw8QE8
    http-api-data-0.5.1-KYwrn1aJ31FNgnInn5Cli
    lift-type-0.1.2.0-BreIDgj4Jmf5OkDoWwKITi
    monad-logger-0.3.41-8rfbOXrEGd8DfyH2lBx4r mtl-2.2.2
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    resource-pool-0.2.3.2-IifXbgA91jhCAUrzrH22km
    resourcet-1.2.6-Dvb859hDcLrAD3xzV7aYNC
    scientific-0.3.7.0-CRm8E7lQFQyIDH2IUurUTy
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-ABUGp25SYaP2g0TAPlG59I
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.0-GCGuYURqqybKqtlFVsyJQb
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-4c1XIGAoQE4JZSLkR4PXOi
    vault-0.3.1.5-2s3VFB16j8TGvblQrERBIg
    vector-0.13.1.0-7kspXIhsfaQEZQW3lsFmcE

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.14.5.1-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-GcWhM5ugy398lZ7Q734jp9
key:                  persistent-2.14.5.1-GcWhM5ugy398lZ7Q734jp9
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  e27dcbcdeafc4a1d8bc9732e38b4be2d
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-GcWhM5ugy398lZ7Q734jp9
depends:
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA
    attoparsec-0.14.4-41Mp0Rehn85G1bRN4BaFh7 base-4.16.4.0
    base64-bytestring-1.2.1.0-4uOt2Tmyc0i8lodPqODz42
    blaze-html-0.9.2.0-HYtvWoJVRy9EXNTTB6ufVU bytestring-0.11.4.0
    conduit-1.3.6.1-z9AmGJDA6I5e741lyc8Fs containers-0.6.5.1
    deepseq-1.4.6.1 fast-logger-3.1.2-HRfTVNlQd84GlAKlGtHEjK
    http-api-data-0.5.1-JVe04Xa7BT2ABZIESqpX9P
    lift-type-0.1.2.0-5iZEGpeCIL59YrlxUPQjew
    monad-logger-0.3.41-5tN5EOKmvYeB4oKhFwRwQe mtl-2.2.2
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    resource-pool-0.2.3.2-GrGKDSlaR9h1TWThSnotfo
    resourcet-1.2.6-8ZQW1jAmhus439CZ3AdML9
    scientific-0.3.7.0-FF6Yj1fy4Cu6vTh2CP6znD
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-GBz3a39qdn2BDJvePGKPZc
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.0-HnziSVXc9IQ8c2JOI4cY33
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C
    vault-0.3.1.5-DS3zPk3zcSFDY8IR1BK7wl
    vector-0.13.1.0-L0sJ9rsFoTeKCVYCfA24Gj

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
